===== 
MPrint Assistant
===== 
Intro
-------- 
MPrint Assistant attempts to give command line users a simple, fast way to print documents to University of Michigan printers. Unlike the browser MPrint interface, multiple documents can be simultaneously selected and sent to a printer.

Features include:

- Batch printing
- Building search with tab completion
- Document path completion 
- Flags that allow for extremely fast usage
